@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import List, Optional
+from typing import Optional
 
 from dataclasses_jsonschema import JsonSchemaMixin
 
@@ -118,8 +118,14 @@ class ActionStateBefore(Event):
     @dataclass
     class Data(JsonSchemaMixin):
 
-        action_id: str
-        parameters: List[str]
+        # required for projects with logic (where actions are defined in the project)
+        # might be also filled for projects without logic
+        action_id: Optional[str] = None
+        parameters: Optional[list[str]] = None
+
+        # required for projects with logic
+        # might or might not be set in other cases
+        action_point_ids: Optional[set[str]] = None
 
     data: Data
 
@@ -133,6 +139,6 @@ class ActionStateAfter(Event):
     class Data(JsonSchemaMixin):
 
         action_id: str
-        results: Optional[List[str]] = None
+        results: Optional[list[str]] = None
 
     data: Data
