@@ -1,23 +1,25 @@
 import abc
-import json
-from typing import Any, List, Type
+from typing import Any
 
-from arcor2.data.common import ActionParameter, Project, Scene
+from arcor2 import json
+from arcor2.cached import CachedProject as CProject
+from arcor2.cached import CachedScene as CScene
+from arcor2.data.common import ActionParameter
 from arcor2.parameter_plugins.base import ParameterPlugin, ParameterPluginException, TypesDict
 
 
-def get_type_name(base: Type[ParameterPlugin]) -> str:
+def get_type_name(base: type[ParameterPlugin]) -> str:
     return f"{base.type_name()}_array"
 
 
 class ListParameterPlugin(ParameterPlugin):
-
     @classmethod
     @abc.abstractmethod
-    def value(cls, type_defs: TypesDict, scene: Scene, project: Project, action_id: str, parameter_id: str) \
-            -> List[Any]:
+    def parameter_value(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> list[Any]:
 
-        val = super(ListParameterPlugin, cls).value(type_defs, scene, project, action_id, parameter_id)
+        val = super(ListParameterPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
 
         if not isinstance(val, list):
             raise ParameterPluginException("Not a list!")
@@ -27,7 +29,7 @@ class ListParameterPlugin(ParameterPlugin):
         return val
 
     @classmethod
-    def param_value_list(cls, param: ActionParameter) -> List[str]:
+    def _param_value_list(cls, param: ActionParameter) -> list[str]:
 
         lst = json.loads(param.value)
 
